
From: Rusty Russell <rusty@rustcorp.com.au>

MODULE_PARM() was marked obsolete.  Remove it from everything except
drivers/ and arch/.

Naturally, such a widespread change may introduce bugs for some of the
non-trivial cases, and where in doubt I used "0" as permissions arg (ie. 
won't appear in sysfs).  Individual authors should think about whether that
would be useful.

Signed-off-by: Rusty Russell <rusty@rustcorp.com.au>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/crypto/tcrypt.c               |    3 ++-
 25-akpm/fs/afs/main.c                 |    3 ++-
 25-akpm/fs/ntfs/super.c               |    3 ++-
 25-akpm/net/irda/irlan/irlan_common.c |    5 +++--
 25-akpm/net/sched/sch_teql.c          |    3 ++-
 5 files changed, 11 insertions(+), 6 deletions(-)

diff -puN crypto/tcrypt.c~mostly-remove-module_parm crypto/tcrypt.c
--- 25/crypto/tcrypt.c~mostly-remove-module_parm	2004-08-24 21:44:01.310125560 -0700
+++ 25-akpm/crypto/tcrypt.c	2004-08-24 21:44:01.325123280 -0700
@@ -24,6 +24,7 @@
 #include <linux/string.h>
 #include <linux/crypto.h>
 #include <linux/highmem.h>
+#include <linux/moduleparam.h>
 #include "tcrypt.h"
 
 /*
@@ -853,7 +854,7 @@ static void __exit fini(void) { }
 module_init(init);
 module_exit(fini);
 
-MODULE_PARM(mode, "i");
+module_param(mode, int, 0);
 
 MODULE_LICENSE("GPL");
 MODULE_DESCRIPTION("Quick & dirty crypto testing module");
diff -puN fs/afs/main.c~mostly-remove-module_parm fs/afs/main.c
--- 25/fs/afs/main.c~mostly-remove-module_parm	2004-08-24 21:44:01.312125256 -0700
+++ 25-akpm/fs/afs/main.c	2004-08-24 21:44:01.326123128 -0700
@@ -10,6 +10,7 @@
  */
 
 #include <linux/module.h>
+#include <linux/moduleparam.h>
 #include <linux/init.h>
 #include <linux/sched.h>
 #include <linux/completion.h>
@@ -47,7 +48,7 @@ MODULE_LICENSE("GPL");
 
 static char *rootcell;
 
-MODULE_PARM(rootcell, "s");
+module_param(rootcell, charp, 0);
 MODULE_PARM_DESC(rootcell, "root AFS cell name and VL server IP addr list");
 
 
diff -puN fs/ntfs/super.c~mostly-remove-module_parm fs/ntfs/super.c
--- 25/fs/ntfs/super.c~mostly-remove-module_parm	2004-08-24 21:44:01.314124952 -0700
+++ 25-akpm/fs/ntfs/super.c	2004-08-24 21:44:01.329122672 -0700
@@ -28,6 +28,7 @@
 #include <linux/backing-dev.h>
 #include <linux/buffer_head.h>
 #include <linux/vfs.h>
+#include <linux/moduleparam.h>
 
 #include "ntfs.h"
 #include "sysctl.h"
@@ -2724,7 +2725,7 @@ MODULE_AUTHOR("Anton Altaparmakov <aia21
 MODULE_DESCRIPTION("NTFS 1.2/3.x driver - Copyright (c) 2001-2004 Anton Altaparmakov");
 MODULE_LICENSE("GPL");
 #ifdef DEBUG
-MODULE_PARM(debug_msgs, "i");
+module_param(debug_msgs, bool, 0);
 MODULE_PARM_DESC(debug_msgs, "Enable debug messages.");
 #endif
 
diff -puN net/irda/irlan/irlan_common.c~mostly-remove-module_parm net/irda/irlan/irlan_common.c
--- 25/net/irda/irlan/irlan_common.c~mostly-remove-module_parm	2004-08-24 21:44:01.317124496 -0700
+++ 25-akpm/net/irda/irlan/irlan_common.c	2004-08-24 21:44:01.331122368 -0700
@@ -36,6 +36,7 @@
 #include <linux/netdevice.h>
 #include <linux/etherdevice.h>
 #include <linux/rtnetlink.h>
+#include <linux/moduleparam.h>
 
 #include <asm/system.h>
 #include <asm/bitops.h>
@@ -1181,9 +1182,9 @@ MODULE_AUTHOR("Dag Brattli <dagb@cs.uit.
 MODULE_DESCRIPTION("The Linux IrDA LAN protocol"); 
 MODULE_LICENSE("GPL");
 
-MODULE_PARM(eth, "i");
+module_param(eth, bool, 0);
 MODULE_PARM_DESC(eth, "Name devices ethX (0) or irlanX (1)");
-MODULE_PARM(access, "i");
+module_param(access, int, 0);
 MODULE_PARM_DESC(access, "Access type DIRECT=1, PEER=2, HOSTED=3");
 
 module_init(irlan_init);
diff -puN net/sched/sch_teql.c~mostly-remove-module_parm net/sched/sch_teql.c
--- 25/net/sched/sch_teql.c~mostly-remove-module_parm	2004-08-24 21:44:01.319124192 -0700
+++ 25-akpm/net/sched/sch_teql.c	2004-08-24 21:44:01.332122216 -0700
@@ -31,6 +31,7 @@
 #include <net/ip.h>
 #include <net/route.h>
 #include <linux/skbuff.h>
+#include <linux/moduleparam.h>
 #include <net/sock.h>
 #include <net/pkt_sched.h>
 
@@ -449,7 +450,7 @@ static __init void teql_master_setup(str
 
 static LIST_HEAD(master_dev_list);
 static int max_equalizers = 1;
-MODULE_PARM(max_equalizers, "i");
+module_param(max_equalizers, int, 0);
 MODULE_PARM_DESC(max_equalizers, "Max number of link equalizers");
 
 static int __init teql_init(void)
_
